/*
 * This file was generated by orbit-idl-2 - DO NOT EDIT!
 */

#ifndef Evolution_DataServer_Mail_H
#define Evolution_DataServer_Mail_H 1
#include <glib.h>
#define ORBIT_IDL_SERIAL 20
#include <orbit/orbit-types.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/** typedefs **/
#include <bonobo/Bonobo.h>
#if !defined(_Evolution_Mail_PropertyName_defined)
#define _Evolution_Mail_PropertyName_defined 1
typedef CORBA_string Evolution_Mail_PropertyName;
#define Evolution_Mail_PropertyName_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define Evolution_Mail_PropertyName_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_PropertyName_0)
#define TC_IMPL_TC_Evolution_Mail_PropertyName_0 'E'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_1 'v'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_2 'o'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_3 'l'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_4 'u'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_5 't'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_6 'i'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_7 'o'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_8 'n'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_9 '_'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_10 'D'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_11 'a'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_12 't'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_13 'a'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_14 'S'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_15 'e'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_16 'r'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_17 'v'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_18 'e'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_19 'r'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_20 '_'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_21 'M'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_22 'a'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_23 'i'
#define TC_IMPL_TC_Evolution_Mail_PropertyName_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_PropertyName_struct;
#define TC_Evolution_Mail_PropertyName ((CORBA_TypeCode)&TC_Evolution_Mail_PropertyName_struct)
#endif
#define Evolution_Mail_PropertyName__alloc() ((Evolution_Mail_PropertyName *)ORBit_small_alloc (TC_CORBA_string))
#define Evolution_Mail_PropertyName__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_string)
#define ORBIT_DECL_CORBA_sequence_CORBA_string 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_0 'E'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_10 'D'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_12 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_13 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_14 'S'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_15 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_16 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_17 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_18 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_19 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_20 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_21 'M'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_22 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_23 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_24 'l'
#if !defined(_CORBA_sequence_CORBA_string_defined)
#define _CORBA_sequence_CORBA_string_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_string* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_string;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_string_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_0 'E'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_10 'D'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_12 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_13 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_14 'S'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_15 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_16 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_17 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_18 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_19 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_20 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_21 'M'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_22 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_23 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct;
#define TC_CORBA_sequence_CORBA_string ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct)
#endif
#define CORBA_sequence_CORBA_string__alloc() ((CORBA_sequence_CORBA_string *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define CORBA_sequence_CORBA_string__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_PropertyName)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_PropertyName 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_PropertyName_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_PropertyName_defined)
#define _CORBA_sequence_Evolution_Mail_PropertyName_defined 1
typedef CORBA_sequence_CORBA_string CORBA_sequence_Evolution_Mail_PropertyName;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_PropertyName_struct;
#define TC_CORBA_sequence_Evolution_Mail_PropertyName ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_PropertyName_struct)
#endif
#define CORBA_sequence_Evolution_Mail_PropertyName__alloc CORBA_sequence_CORBA_string__alloc
#define CORBA_sequence_Evolution_Mail_PropertyName__freekids CORBA_sequence_CORBA_string__freekids
#define CORBA_sequence_Evolution_Mail_PropertyName_allocbuf CORBA_sequence_CORBA_string_allocbuf
#define CORBA_sequence_Evolution_Mail_PropertyName_marshal(x,y,z) CORBA_sequence_CORBA_string_marshal((x),(y),(z))
#define CORBA_sequence_Evolution_Mail_PropertyName_demarshal(x,y,z,i) CORBA_sequence_CORBA_string_demarshal((x),(y),(z),(i))
#endif
#if !defined(_Evolution_Mail_PropertyNames_defined)
#define _Evolution_Mail_PropertyNames_defined 1
typedef CORBA_sequence_Evolution_Mail_PropertyName Evolution_Mail_PropertyNames;
#define Evolution_Mail_PropertyNames_marshal(x,y,z) CORBA_sequence_Evolution_Mail_PropertyName_marshal((x),(y),(z))
#define Evolution_Mail_PropertyNames_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_PropertyName_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_PropertyNames_0)
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_0 'E'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_1 'v'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_2 'o'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_3 'l'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_4 'u'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_5 't'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_6 'i'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_7 'o'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_8 'n'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_9 '_'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_10 'D'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_11 'a'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_12 't'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_13 'a'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_14 'S'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_15 'e'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_16 'r'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_17 'v'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_18 'e'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_19 'r'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_20 '_'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_21 'M'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_22 'a'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_23 'i'
#define TC_IMPL_TC_Evolution_Mail_PropertyNames_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_PropertyNames_struct;
#define TC_Evolution_Mail_PropertyNames ((CORBA_TypeCode)&TC_Evolution_Mail_PropertyNames_struct)
#endif
#define Evolution_Mail_PropertyNames__alloc() ((Evolution_Mail_PropertyNames *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_PropertyName))
#define Evolution_Mail_PropertyNames__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_PropertyName,(m),(d))
#define Evolution_Mail_PropertyNames_allocbuf(l) ((Evolution_Mail_PropertyName*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_PropertyName, (l)))
#endif
#if !defined(_Evolution_Mail_Property_defined)
#define _Evolution_Mail_Property_defined 1
typedef struct Evolution_Mail_Property_type Evolution_Mail_Property;
struct Evolution_Mail_Property_type {
Evolution_Mail_PropertyName name;
CORBA_any value;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_Property_0)
#define TC_IMPL_TC_Evolution_Mail_Property_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Property_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Property_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Property_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Property_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Property_5 't'
#define TC_IMPL_TC_Evolution_Mail_Property_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Property_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Property_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Property_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Property_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Property_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Property_12 't'
#define TC_IMPL_TC_Evolution_Mail_Property_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Property_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Property_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Property_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Property_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Property_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Property_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Property_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Property_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Property_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Property_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Property_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Property_struct;
#define TC_Evolution_Mail_Property ((CORBA_TypeCode)&TC_Evolution_Mail_Property_struct)
#endif
#define Evolution_Mail_Property__alloc() ((Evolution_Mail_Property *)ORBit_small_alloc (TC_Evolution_Mail_Property))
#define Evolution_Mail_Property__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_Property,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_Property)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_Property 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Property_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_Property_defined)
#define _CORBA_sequence_Evolution_Mail_Property_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_Property* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_Property;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Property_struct;
#define TC_CORBA_sequence_Evolution_Mail_Property ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_Property_struct)
#endif
#define CORBA_sequence_Evolution_Mail_Property__alloc() ((CORBA_sequence_Evolution_Mail_Property *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_Property))
#define CORBA_sequence_Evolution_Mail_Property__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_Property,(m),(d))
#define CORBA_sequence_Evolution_Mail_Property_allocbuf(l) ((Evolution_Mail_Property*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_Property, (l)))
#define CORBA_sequence_Evolution_Mail_Property_allocbuf(l) ((Evolution_Mail_Property*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_Property, (l)))
#endif
#if !defined(_Evolution_Mail_Properties_defined)
#define _Evolution_Mail_Properties_defined 1
typedef CORBA_sequence_Evolution_Mail_Property Evolution_Mail_Properties;
#define Evolution_Mail_Properties_marshal(x,y,z) CORBA_sequence_Evolution_Mail_Property_marshal((x),(y),(z))
#define Evolution_Mail_Properties_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_Property_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_Properties_0)
#define TC_IMPL_TC_Evolution_Mail_Properties_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Properties_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Properties_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Properties_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Properties_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Properties_5 't'
#define TC_IMPL_TC_Evolution_Mail_Properties_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Properties_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Properties_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Properties_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Properties_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Properties_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Properties_12 't'
#define TC_IMPL_TC_Evolution_Mail_Properties_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Properties_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Properties_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Properties_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Properties_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Properties_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Properties_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Properties_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Properties_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Properties_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Properties_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Properties_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Properties_struct;
#define TC_Evolution_Mail_Properties ((CORBA_TypeCode)&TC_Evolution_Mail_Properties_struct)
#endif
#define Evolution_Mail_Properties__alloc() ((Evolution_Mail_Properties *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_Property))
#define Evolution_Mail_Properties__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_Property,(m),(d))
#define Evolution_Mail_Properties_allocbuf(l) ((Evolution_Mail_Property*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_Property, (l)))
#endif
#if !defined(_Evolution_Mail_ErrorType_defined)
#define _Evolution_Mail_ErrorType_defined 1
typedef enum {
  Evolution_Mail_SYSTEM_ERROR,
  Evolution_Mail_CAMEL_ERROR,
  Evolution_Mail_FAILED,
  Evolution_Mail_NOT_SUPPORTED,
  Evolution_Mail_NO_PERMISSION
} Evolution_Mail_ErrorType;
#if !defined(TC_IMPL_TC_Evolution_Mail_ErrorType_0)
#define TC_IMPL_TC_Evolution_Mail_ErrorType_0 'E'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_1 'v'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_2 'o'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_3 'l'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_4 'u'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_5 't'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_6 'i'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_7 'o'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_8 'n'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_9 '_'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_10 'D'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_11 'a'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_12 't'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_13 'a'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_14 'S'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_15 'e'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_16 'r'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_17 'v'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_18 'e'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_19 'r'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_20 '_'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_21 'M'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_22 'a'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_23 'i'
#define TC_IMPL_TC_Evolution_Mail_ErrorType_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_ErrorType_struct;
#define TC_Evolution_Mail_ErrorType ((CORBA_TypeCode)&TC_Evolution_Mail_ErrorType_struct)
#endif
#endif
#undef ex_Evolution_Mail_MailException
#define ex_Evolution_Mail_MailException "IDL:Evolution/Mail/MailException:1.0"
#if !defined(_Evolution_Mail_MailException_defined)
#define _Evolution_Mail_MailException_defined 1
typedef struct Evolution_Mail_MailException_type Evolution_Mail_MailException;
struct Evolution_Mail_MailException_type {
Evolution_Mail_ErrorType id;
CORBA_string desc;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_MailException_0)
#define TC_IMPL_TC_Evolution_Mail_MailException_0 'E'
#define TC_IMPL_TC_Evolution_Mail_MailException_1 'v'
#define TC_IMPL_TC_Evolution_Mail_MailException_2 'o'
#define TC_IMPL_TC_Evolution_Mail_MailException_3 'l'
#define TC_IMPL_TC_Evolution_Mail_MailException_4 'u'
#define TC_IMPL_TC_Evolution_Mail_MailException_5 't'
#define TC_IMPL_TC_Evolution_Mail_MailException_6 'i'
#define TC_IMPL_TC_Evolution_Mail_MailException_7 'o'
#define TC_IMPL_TC_Evolution_Mail_MailException_8 'n'
#define TC_IMPL_TC_Evolution_Mail_MailException_9 '_'
#define TC_IMPL_TC_Evolution_Mail_MailException_10 'D'
#define TC_IMPL_TC_Evolution_Mail_MailException_11 'a'
#define TC_IMPL_TC_Evolution_Mail_MailException_12 't'
#define TC_IMPL_TC_Evolution_Mail_MailException_13 'a'
#define TC_IMPL_TC_Evolution_Mail_MailException_14 'S'
#define TC_IMPL_TC_Evolution_Mail_MailException_15 'e'
#define TC_IMPL_TC_Evolution_Mail_MailException_16 'r'
#define TC_IMPL_TC_Evolution_Mail_MailException_17 'v'
#define TC_IMPL_TC_Evolution_Mail_MailException_18 'e'
#define TC_IMPL_TC_Evolution_Mail_MailException_19 'r'
#define TC_IMPL_TC_Evolution_Mail_MailException_20 '_'
#define TC_IMPL_TC_Evolution_Mail_MailException_21 'M'
#define TC_IMPL_TC_Evolution_Mail_MailException_22 'a'
#define TC_IMPL_TC_Evolution_Mail_MailException_23 'i'
#define TC_IMPL_TC_Evolution_Mail_MailException_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MailException_struct;
#define TC_Evolution_Mail_MailException ((CORBA_TypeCode)&TC_Evolution_Mail_MailException_struct)
#endif
#define Evolution_Mail_MailException__alloc() ((Evolution_Mail_MailException *)ORBit_small_alloc (TC_Evolution_Mail_MailException))
#define Evolution_Mail_MailException__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_MailException,(m),(d))
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_Folder) && !defined(_Evolution_Mail_Folder_defined)
#define ORBIT_DECL_Evolution_Mail_Folder 1
#define _Evolution_Mail_Folder_defined 1
#define Evolution_Mail_Folder__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_Folder;
extern CORBA_unsigned_long Evolution_Mail_Folder__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_Folder_0)
#define TC_IMPL_TC_Evolution_Mail_Folder_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Folder_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Folder_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Folder_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Folder_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Folder_5 't'
#define TC_IMPL_TC_Evolution_Mail_Folder_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Folder_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Folder_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Folder_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Folder_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Folder_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Folder_12 't'
#define TC_IMPL_TC_Evolution_Mail_Folder_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Folder_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Folder_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Folder_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Folder_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Folder_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Folder_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Folder_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Folder_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Folder_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Folder_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Folder_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Folder_struct;
#define TC_Evolution_Mail_Folder ((CORBA_TypeCode)&TC_Evolution_Mail_Folder_struct)
#endif
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_Object)
#define ORBIT_DECL_CORBA_sequence_CORBA_Object 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_0 'E'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_10 'D'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_12 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_13 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_14 'S'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_15 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_16 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_17 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_18 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_19 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_20 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_21 'M'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_22 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_23 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_24 'l'
#if !defined(_CORBA_sequence_CORBA_Object_defined)
#define _CORBA_sequence_CORBA_Object_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_Object* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_Object;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_Object_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_0 'E'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_10 'D'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_12 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_13 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_14 'S'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_15 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_16 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_17 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_18 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_19 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_20 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_21 'M'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_22 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_23 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_Object_struct;
#define TC_CORBA_sequence_CORBA_Object ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_Object_struct)
#endif
#define CORBA_sequence_CORBA_Object__alloc() ((CORBA_sequence_CORBA_Object *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_Object))
#define CORBA_sequence_CORBA_Object__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_Object,(m),(d))
#define CORBA_sequence_CORBA_Object_allocbuf(l) ((CORBA_Object*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_Object, (l)))
#define CORBA_sequence_CORBA_Object_allocbuf(l) ((CORBA_Object*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_Object, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_Folder)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_Folder 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Folder_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_Folder_defined)
#define _CORBA_sequence_Evolution_Mail_Folder_defined 1
typedef CORBA_sequence_CORBA_Object CORBA_sequence_Evolution_Mail_Folder;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Folder_struct;
#define TC_CORBA_sequence_Evolution_Mail_Folder ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_Folder_struct)
#endif
#define CORBA_sequence_Evolution_Mail_Folder__alloc CORBA_sequence_CORBA_Object__alloc
#define CORBA_sequence_Evolution_Mail_Folder__freekids CORBA_sequence_CORBA_Object__freekids
#define CORBA_sequence_Evolution_Mail_Folder_allocbuf CORBA_sequence_CORBA_Object_allocbuf
#define CORBA_sequence_Evolution_Mail_Folder_marshal(x,y,z) CORBA_sequence_CORBA_Object_marshal((x),(y),(z))
#define CORBA_sequence_Evolution_Mail_Folder_demarshal(x,y,z,i) CORBA_sequence_CORBA_Object_demarshal((x),(y),(z),(i))
#endif
#if !defined(_Evolution_Mail_Folders_defined)
#define _Evolution_Mail_Folders_defined 1
typedef CORBA_sequence_Evolution_Mail_Folder Evolution_Mail_Folders;
#define Evolution_Mail_Folders_marshal(x,y,z) CORBA_sequence_Evolution_Mail_Folder_marshal((x),(y),(z))
#define Evolution_Mail_Folders_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_Folder_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_Folders_0)
#define TC_IMPL_TC_Evolution_Mail_Folders_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Folders_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Folders_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Folders_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Folders_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Folders_5 't'
#define TC_IMPL_TC_Evolution_Mail_Folders_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Folders_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Folders_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Folders_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Folders_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Folders_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Folders_12 't'
#define TC_IMPL_TC_Evolution_Mail_Folders_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Folders_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Folders_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Folders_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Folders_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Folders_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Folders_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Folders_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Folders_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Folders_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Folders_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Folders_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Folders_struct;
#define TC_Evolution_Mail_Folders ((CORBA_TypeCode)&TC_Evolution_Mail_Folders_struct)
#endif
#define Evolution_Mail_Folders__alloc() ((Evolution_Mail_Folders *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_Folder))
#define Evolution_Mail_Folders__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_Folder,(m),(d))
#define Evolution_Mail_Folders_allocbuf(l) ((Evolution_Mail_Folder*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_Folder, (l)))
#endif
#if !defined(_Evolution_Mail_FolderInfo_defined)
#define _Evolution_Mail_FolderInfo_defined 1
typedef struct Evolution_Mail_FolderInfo_type Evolution_Mail_FolderInfo;
struct Evolution_Mail_FolderInfo_type {
CORBA_string name;
CORBA_string full_name;
Evolution_Mail_Folder folder;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_FolderInfo_0)
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_0 'E'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_1 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_2 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_3 'l'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_4 'u'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_5 't'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_6 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_7 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_8 'n'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_9 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_10 'D'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_11 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_12 't'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_13 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_14 'S'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_15 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_16 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_17 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_18 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_19 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_20 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_21 'M'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_22 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_23 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderInfo_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderInfo_struct;
#define TC_Evolution_Mail_FolderInfo ((CORBA_TypeCode)&TC_Evolution_Mail_FolderInfo_struct)
#endif
#define Evolution_Mail_FolderInfo__alloc() ((Evolution_Mail_FolderInfo *)ORBit_small_alloc (TC_Evolution_Mail_FolderInfo))
#define Evolution_Mail_FolderInfo__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_FolderInfo,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_FolderInfo)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_FolderInfo 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderInfo_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_FolderInfo_defined)
#define _CORBA_sequence_Evolution_Mail_FolderInfo_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_FolderInfo* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_FolderInfo;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_FolderInfo_struct;
#define TC_CORBA_sequence_Evolution_Mail_FolderInfo ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_FolderInfo_struct)
#endif
#define CORBA_sequence_Evolution_Mail_FolderInfo__alloc() ((CORBA_sequence_Evolution_Mail_FolderInfo *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_FolderInfo))
#define CORBA_sequence_Evolution_Mail_FolderInfo__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_FolderInfo,(m),(d))
#define CORBA_sequence_Evolution_Mail_FolderInfo_allocbuf(l) ((Evolution_Mail_FolderInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_FolderInfo, (l)))
#define CORBA_sequence_Evolution_Mail_FolderInfo_allocbuf(l) ((Evolution_Mail_FolderInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_FolderInfo, (l)))
#endif
#if !defined(_Evolution_Mail_FolderInfos_defined)
#define _Evolution_Mail_FolderInfos_defined 1
typedef CORBA_sequence_Evolution_Mail_FolderInfo Evolution_Mail_FolderInfos;
#define Evolution_Mail_FolderInfos_marshal(x,y,z) CORBA_sequence_Evolution_Mail_FolderInfo_marshal((x),(y),(z))
#define Evolution_Mail_FolderInfos_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_FolderInfo_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_FolderInfos_0)
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_0 'E'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_1 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_2 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_3 'l'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_4 'u'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_5 't'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_6 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_7 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_8 'n'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_9 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_10 'D'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_11 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_12 't'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_13 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_14 'S'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_15 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_16 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_17 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_18 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_19 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_20 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_21 'M'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_22 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_23 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderInfos_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderInfos_struct;
#define TC_Evolution_Mail_FolderInfos ((CORBA_TypeCode)&TC_Evolution_Mail_FolderInfos_struct)
#endif
#define Evolution_Mail_FolderInfos__alloc() ((Evolution_Mail_FolderInfos *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_FolderInfo))
#define Evolution_Mail_FolderInfos__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_FolderInfo,(m),(d))
#define Evolution_Mail_FolderInfos_allocbuf(l) ((Evolution_Mail_FolderInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_FolderInfo, (l)))
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_Store) && !defined(_Evolution_Mail_Store_defined)
#define ORBIT_DECL_Evolution_Mail_Store 1
#define _Evolution_Mail_Store_defined 1
#define Evolution_Mail_Store__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_Store;
extern CORBA_unsigned_long Evolution_Mail_Store__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_Store_0)
#define TC_IMPL_TC_Evolution_Mail_Store_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Store_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Store_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Store_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Store_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Store_5 't'
#define TC_IMPL_TC_Evolution_Mail_Store_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Store_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Store_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Store_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Store_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Store_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Store_12 't'
#define TC_IMPL_TC_Evolution_Mail_Store_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Store_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Store_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Store_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Store_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Store_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Store_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Store_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Store_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Store_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Store_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Store_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Store_struct;
#define TC_Evolution_Mail_Store ((CORBA_TypeCode)&TC_Evolution_Mail_Store_struct)
#endif
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_Object)
#define ORBIT_DECL_CORBA_sequence_CORBA_Object 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_0 'E'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_10 'D'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_12 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_13 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_14 'S'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_15 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_16 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_17 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_18 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_19 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_20 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_21 'M'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_22 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_23 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_Object_24 'l'
#if !defined(_CORBA_sequence_CORBA_Object_defined)
#define _CORBA_sequence_CORBA_Object_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_Object* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_Object;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_Object_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_0 'E'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_10 'D'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_12 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_13 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_14 'S'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_15 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_16 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_17 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_18 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_19 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_20 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_21 'M'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_22 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_23 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_Object_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_Object_struct;
#define TC_CORBA_sequence_CORBA_Object ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_Object_struct)
#endif
#define CORBA_sequence_CORBA_Object__alloc() ((CORBA_sequence_CORBA_Object *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_Object))
#define CORBA_sequence_CORBA_Object__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_Object,(m),(d))
#define CORBA_sequence_CORBA_Object_allocbuf(l) ((CORBA_Object*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_Object, (l)))
#define CORBA_sequence_CORBA_Object_allocbuf(l) ((CORBA_Object*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_Object, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_Store)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_Store 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_Store_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_Store_defined)
#define _CORBA_sequence_Evolution_Mail_Store_defined 1
typedef CORBA_sequence_CORBA_Object CORBA_sequence_Evolution_Mail_Store;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Store_struct;
#define TC_CORBA_sequence_Evolution_Mail_Store ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_Store_struct)
#endif
#define CORBA_sequence_Evolution_Mail_Store__alloc CORBA_sequence_CORBA_Object__alloc
#define CORBA_sequence_Evolution_Mail_Store__freekids CORBA_sequence_CORBA_Object__freekids
#define CORBA_sequence_Evolution_Mail_Store_allocbuf CORBA_sequence_CORBA_Object_allocbuf
#define CORBA_sequence_Evolution_Mail_Store_marshal(x,y,z) CORBA_sequence_CORBA_Object_marshal((x),(y),(z))
#define CORBA_sequence_Evolution_Mail_Store_demarshal(x,y,z,i) CORBA_sequence_CORBA_Object_demarshal((x),(y),(z),(i))
#endif
#if !defined(_Evolution_Mail_Stores_defined)
#define _Evolution_Mail_Stores_defined 1
typedef CORBA_sequence_Evolution_Mail_Store Evolution_Mail_Stores;
#define Evolution_Mail_Stores_marshal(x,y,z) CORBA_sequence_Evolution_Mail_Store_marshal((x),(y),(z))
#define Evolution_Mail_Stores_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_Store_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_Stores_0)
#define TC_IMPL_TC_Evolution_Mail_Stores_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Stores_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Stores_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Stores_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Stores_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Stores_5 't'
#define TC_IMPL_TC_Evolution_Mail_Stores_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Stores_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Stores_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Stores_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Stores_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Stores_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Stores_12 't'
#define TC_IMPL_TC_Evolution_Mail_Stores_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Stores_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Stores_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Stores_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Stores_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Stores_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Stores_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Stores_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Stores_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Stores_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Stores_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Stores_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Stores_struct;
#define TC_Evolution_Mail_Stores ((CORBA_TypeCode)&TC_Evolution_Mail_Stores_struct)
#endif
#define Evolution_Mail_Stores__alloc() ((Evolution_Mail_Stores *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_Store))
#define Evolution_Mail_Stores__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_Store,(m),(d))
#define Evolution_Mail_Stores_allocbuf(l) ((Evolution_Mail_Store*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_Store, (l)))
#endif
#if !defined(_Evolution_Mail_StoreInfo_defined)
#define _Evolution_Mail_StoreInfo_defined 1
typedef struct Evolution_Mail_StoreInfo_type Evolution_Mail_StoreInfo;
struct Evolution_Mail_StoreInfo_type {
CORBA_string name;
CORBA_string uid;
Evolution_Mail_Store store;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_StoreInfo_0)
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_0 'E'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_1 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_2 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_3 'l'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_4 'u'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_5 't'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_6 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_7 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_8 'n'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_9 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_10 'D'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_11 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_12 't'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_13 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_14 'S'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_15 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_16 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_17 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_18 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_19 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_20 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_21 'M'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_22 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_23 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreInfo_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreInfo_struct;
#define TC_Evolution_Mail_StoreInfo ((CORBA_TypeCode)&TC_Evolution_Mail_StoreInfo_struct)
#endif
#define Evolution_Mail_StoreInfo__alloc() ((Evolution_Mail_StoreInfo *)ORBit_small_alloc (TC_Evolution_Mail_StoreInfo))
#define Evolution_Mail_StoreInfo__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_StoreInfo,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_StoreInfo)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_StoreInfo 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreInfo_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_StoreInfo_defined)
#define _CORBA_sequence_Evolution_Mail_StoreInfo_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_StoreInfo* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_StoreInfo;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_StoreInfo_struct;
#define TC_CORBA_sequence_Evolution_Mail_StoreInfo ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_StoreInfo_struct)
#endif
#define CORBA_sequence_Evolution_Mail_StoreInfo__alloc() ((CORBA_sequence_Evolution_Mail_StoreInfo *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_StoreInfo))
#define CORBA_sequence_Evolution_Mail_StoreInfo__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_StoreInfo,(m),(d))
#define CORBA_sequence_Evolution_Mail_StoreInfo_allocbuf(l) ((Evolution_Mail_StoreInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_StoreInfo, (l)))
#define CORBA_sequence_Evolution_Mail_StoreInfo_allocbuf(l) ((Evolution_Mail_StoreInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_StoreInfo, (l)))
#endif
#if !defined(_Evolution_Mail_StoreInfos_defined)
#define _Evolution_Mail_StoreInfos_defined 1
typedef CORBA_sequence_Evolution_Mail_StoreInfo Evolution_Mail_StoreInfos;
#define Evolution_Mail_StoreInfos_marshal(x,y,z) CORBA_sequence_Evolution_Mail_StoreInfo_marshal((x),(y),(z))
#define Evolution_Mail_StoreInfos_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_StoreInfo_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_StoreInfos_0)
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_0 'E'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_1 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_2 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_3 'l'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_4 'u'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_5 't'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_6 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_7 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_8 'n'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_9 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_10 'D'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_11 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_12 't'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_13 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_14 'S'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_15 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_16 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_17 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_18 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_19 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_20 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_21 'M'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_22 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_23 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreInfos_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreInfos_struct;
#define TC_Evolution_Mail_StoreInfos ((CORBA_TypeCode)&TC_Evolution_Mail_StoreInfos_struct)
#endif
#define Evolution_Mail_StoreInfos__alloc() ((Evolution_Mail_StoreInfos *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_StoreInfo))
#define Evolution_Mail_StoreInfos__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_StoreInfo,(m),(d))
#define Evolution_Mail_StoreInfos_allocbuf(l) ((Evolution_Mail_StoreInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_StoreInfo, (l)))
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_Session) && !defined(_Evolution_Mail_Session_defined)
#define ORBIT_DECL_Evolution_Mail_Session 1
#define _Evolution_Mail_Session_defined 1
#define Evolution_Mail_Session__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_Session;
extern CORBA_unsigned_long Evolution_Mail_Session__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_Session_0)
#define TC_IMPL_TC_Evolution_Mail_Session_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Session_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Session_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Session_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Session_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Session_5 't'
#define TC_IMPL_TC_Evolution_Mail_Session_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Session_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Session_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Session_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Session_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Session_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Session_12 't'
#define TC_IMPL_TC_Evolution_Mail_Session_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Session_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Session_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Session_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Session_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Session_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Session_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Session_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Session_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Session_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Session_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Session_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Session_struct;
#define TC_Evolution_Mail_Session ((CORBA_TypeCode)&TC_Evolution_Mail_Session_struct)
#endif
#endif
#if !defined(_Evolution_Mail_UserFlag_defined)
#define _Evolution_Mail_UserFlag_defined 1
typedef CORBA_string Evolution_Mail_UserFlag;
#define Evolution_Mail_UserFlag_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define Evolution_Mail_UserFlag_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_UserFlag_0)
#define TC_IMPL_TC_Evolution_Mail_UserFlag_0 'E'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_1 'v'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_2 'o'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_3 'l'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_4 'u'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_5 't'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_6 'i'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_7 'o'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_8 'n'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_9 '_'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_10 'D'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_11 'a'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_12 't'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_13 'a'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_14 'S'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_15 'e'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_16 'r'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_17 'v'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_18 'e'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_19 'r'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_20 '_'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_21 'M'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_22 'a'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_23 'i'
#define TC_IMPL_TC_Evolution_Mail_UserFlag_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_UserFlag_struct;
#define TC_Evolution_Mail_UserFlag ((CORBA_TypeCode)&TC_Evolution_Mail_UserFlag_struct)
#endif
#define Evolution_Mail_UserFlag__alloc() ((Evolution_Mail_UserFlag *)ORBit_small_alloc (TC_CORBA_string))
#define Evolution_Mail_UserFlag__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_string)
#define ORBIT_DECL_CORBA_sequence_CORBA_string 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_0 'E'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_10 'D'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_12 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_13 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_14 'S'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_15 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_16 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_17 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_18 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_19 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_20 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_21 'M'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_22 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_23 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_24 'l'
#if !defined(_CORBA_sequence_CORBA_string_defined)
#define _CORBA_sequence_CORBA_string_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_string* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_string;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_string_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_0 'E'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_10 'D'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_12 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_13 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_14 'S'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_15 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_16 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_17 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_18 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_19 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_20 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_21 'M'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_22 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_23 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct;
#define TC_CORBA_sequence_CORBA_string ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct)
#endif
#define CORBA_sequence_CORBA_string__alloc() ((CORBA_sequence_CORBA_string *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define CORBA_sequence_CORBA_string__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_UserFlag)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_UserFlag 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserFlag_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_UserFlag_defined)
#define _CORBA_sequence_Evolution_Mail_UserFlag_defined 1
typedef CORBA_sequence_CORBA_string CORBA_sequence_Evolution_Mail_UserFlag;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_UserFlag_struct;
#define TC_CORBA_sequence_Evolution_Mail_UserFlag ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_UserFlag_struct)
#endif
#define CORBA_sequence_Evolution_Mail_UserFlag__alloc CORBA_sequence_CORBA_string__alloc
#define CORBA_sequence_Evolution_Mail_UserFlag__freekids CORBA_sequence_CORBA_string__freekids
#define CORBA_sequence_Evolution_Mail_UserFlag_allocbuf CORBA_sequence_CORBA_string_allocbuf
#define CORBA_sequence_Evolution_Mail_UserFlag_marshal(x,y,z) CORBA_sequence_CORBA_string_marshal((x),(y),(z))
#define CORBA_sequence_Evolution_Mail_UserFlag_demarshal(x,y,z,i) CORBA_sequence_CORBA_string_demarshal((x),(y),(z),(i))
#endif
#if !defined(_Evolution_Mail_UserFlags_defined)
#define _Evolution_Mail_UserFlags_defined 1
typedef CORBA_sequence_Evolution_Mail_UserFlag Evolution_Mail_UserFlags;
#define Evolution_Mail_UserFlags_marshal(x,y,z) CORBA_sequence_Evolution_Mail_UserFlag_marshal((x),(y),(z))
#define Evolution_Mail_UserFlags_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_UserFlag_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_UserFlags_0)
#define TC_IMPL_TC_Evolution_Mail_UserFlags_0 'E'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_1 'v'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_2 'o'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_3 'l'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_4 'u'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_5 't'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_6 'i'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_7 'o'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_8 'n'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_9 '_'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_10 'D'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_11 'a'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_12 't'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_13 'a'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_14 'S'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_15 'e'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_16 'r'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_17 'v'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_18 'e'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_19 'r'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_20 '_'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_21 'M'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_22 'a'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_23 'i'
#define TC_IMPL_TC_Evolution_Mail_UserFlags_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_UserFlags_struct;
#define TC_Evolution_Mail_UserFlags ((CORBA_TypeCode)&TC_Evolution_Mail_UserFlags_struct)
#endif
#define Evolution_Mail_UserFlags__alloc() ((Evolution_Mail_UserFlags *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_UserFlag))
#define Evolution_Mail_UserFlags__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_UserFlag,(m),(d))
#define Evolution_Mail_UserFlags_allocbuf(l) ((Evolution_Mail_UserFlag*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_UserFlag, (l)))
#endif
#if !defined(_Evolution_Mail_UserTag_defined)
#define _Evolution_Mail_UserTag_defined 1
typedef struct Evolution_Mail_UserTag_type Evolution_Mail_UserTag;
struct Evolution_Mail_UserTag_type {
CORBA_string name;
CORBA_string value;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_UserTag_0)
#define TC_IMPL_TC_Evolution_Mail_UserTag_0 'E'
#define TC_IMPL_TC_Evolution_Mail_UserTag_1 'v'
#define TC_IMPL_TC_Evolution_Mail_UserTag_2 'o'
#define TC_IMPL_TC_Evolution_Mail_UserTag_3 'l'
#define TC_IMPL_TC_Evolution_Mail_UserTag_4 'u'
#define TC_IMPL_TC_Evolution_Mail_UserTag_5 't'
#define TC_IMPL_TC_Evolution_Mail_UserTag_6 'i'
#define TC_IMPL_TC_Evolution_Mail_UserTag_7 'o'
#define TC_IMPL_TC_Evolution_Mail_UserTag_8 'n'
#define TC_IMPL_TC_Evolution_Mail_UserTag_9 '_'
#define TC_IMPL_TC_Evolution_Mail_UserTag_10 'D'
#define TC_IMPL_TC_Evolution_Mail_UserTag_11 'a'
#define TC_IMPL_TC_Evolution_Mail_UserTag_12 't'
#define TC_IMPL_TC_Evolution_Mail_UserTag_13 'a'
#define TC_IMPL_TC_Evolution_Mail_UserTag_14 'S'
#define TC_IMPL_TC_Evolution_Mail_UserTag_15 'e'
#define TC_IMPL_TC_Evolution_Mail_UserTag_16 'r'
#define TC_IMPL_TC_Evolution_Mail_UserTag_17 'v'
#define TC_IMPL_TC_Evolution_Mail_UserTag_18 'e'
#define TC_IMPL_TC_Evolution_Mail_UserTag_19 'r'
#define TC_IMPL_TC_Evolution_Mail_UserTag_20 '_'
#define TC_IMPL_TC_Evolution_Mail_UserTag_21 'M'
#define TC_IMPL_TC_Evolution_Mail_UserTag_22 'a'
#define TC_IMPL_TC_Evolution_Mail_UserTag_23 'i'
#define TC_IMPL_TC_Evolution_Mail_UserTag_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_UserTag_struct;
#define TC_Evolution_Mail_UserTag ((CORBA_TypeCode)&TC_Evolution_Mail_UserTag_struct)
#endif
#define Evolution_Mail_UserTag__alloc() ((Evolution_Mail_UserTag *)ORBit_small_alloc (TC_Evolution_Mail_UserTag))
#define Evolution_Mail_UserTag__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_UserTag,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_UserTag)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_UserTag 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_UserTag_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_UserTag_defined)
#define _CORBA_sequence_Evolution_Mail_UserTag_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_UserTag* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_UserTag;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_UserTag_struct;
#define TC_CORBA_sequence_Evolution_Mail_UserTag ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_UserTag_struct)
#endif
#define CORBA_sequence_Evolution_Mail_UserTag__alloc() ((CORBA_sequence_Evolution_Mail_UserTag *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_UserTag))
#define CORBA_sequence_Evolution_Mail_UserTag__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_UserTag,(m),(d))
#define CORBA_sequence_Evolution_Mail_UserTag_allocbuf(l) ((Evolution_Mail_UserTag*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_UserTag, (l)))
#define CORBA_sequence_Evolution_Mail_UserTag_allocbuf(l) ((Evolution_Mail_UserTag*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_UserTag, (l)))
#endif
#if !defined(_Evolution_Mail_UserTags_defined)
#define _Evolution_Mail_UserTags_defined 1
typedef CORBA_sequence_Evolution_Mail_UserTag Evolution_Mail_UserTags;
#define Evolution_Mail_UserTags_marshal(x,y,z) CORBA_sequence_Evolution_Mail_UserTag_marshal((x),(y),(z))
#define Evolution_Mail_UserTags_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_UserTag_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_UserTags_0)
#define TC_IMPL_TC_Evolution_Mail_UserTags_0 'E'
#define TC_IMPL_TC_Evolution_Mail_UserTags_1 'v'
#define TC_IMPL_TC_Evolution_Mail_UserTags_2 'o'
#define TC_IMPL_TC_Evolution_Mail_UserTags_3 'l'
#define TC_IMPL_TC_Evolution_Mail_UserTags_4 'u'
#define TC_IMPL_TC_Evolution_Mail_UserTags_5 't'
#define TC_IMPL_TC_Evolution_Mail_UserTags_6 'i'
#define TC_IMPL_TC_Evolution_Mail_UserTags_7 'o'
#define TC_IMPL_TC_Evolution_Mail_UserTags_8 'n'
#define TC_IMPL_TC_Evolution_Mail_UserTags_9 '_'
#define TC_IMPL_TC_Evolution_Mail_UserTags_10 'D'
#define TC_IMPL_TC_Evolution_Mail_UserTags_11 'a'
#define TC_IMPL_TC_Evolution_Mail_UserTags_12 't'
#define TC_IMPL_TC_Evolution_Mail_UserTags_13 'a'
#define TC_IMPL_TC_Evolution_Mail_UserTags_14 'S'
#define TC_IMPL_TC_Evolution_Mail_UserTags_15 'e'
#define TC_IMPL_TC_Evolution_Mail_UserTags_16 'r'
#define TC_IMPL_TC_Evolution_Mail_UserTags_17 'v'
#define TC_IMPL_TC_Evolution_Mail_UserTags_18 'e'
#define TC_IMPL_TC_Evolution_Mail_UserTags_19 'r'
#define TC_IMPL_TC_Evolution_Mail_UserTags_20 '_'
#define TC_IMPL_TC_Evolution_Mail_UserTags_21 'M'
#define TC_IMPL_TC_Evolution_Mail_UserTags_22 'a'
#define TC_IMPL_TC_Evolution_Mail_UserTags_23 'i'
#define TC_IMPL_TC_Evolution_Mail_UserTags_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_UserTags_struct;
#define TC_Evolution_Mail_UserTags ((CORBA_TypeCode)&TC_Evolution_Mail_UserTags_struct)
#endif
#define Evolution_Mail_UserTags__alloc() ((Evolution_Mail_UserTags *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_UserTag))
#define Evolution_Mail_UserTags__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_UserTag,(m),(d))
#define Evolution_Mail_UserTags_allocbuf(l) ((Evolution_Mail_UserTag*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_UserTag, (l)))
#endif
#if !defined(_Evolution_Mail_MessageInfo_defined)
#define _Evolution_Mail_MessageInfo_defined 1
typedef struct Evolution_Mail_MessageInfo_type Evolution_Mail_MessageInfo;
struct Evolution_Mail_MessageInfo_type {
CORBA_string uid;
CORBA_string subject;
CORBA_string to;
CORBA_string from;
CORBA_long flags;
Evolution_Mail_UserFlags userFlags;
Evolution_Mail_UserTags userTags;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_MessageInfo_0)
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_0 'E'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_1 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_2 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_3 'l'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_4 'u'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_5 't'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_6 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_7 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_8 'n'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_9 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_10 'D'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_11 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_12 't'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_13 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_14 'S'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_15 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_16 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_17 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_18 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_19 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_20 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_21 'M'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_22 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_23 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageInfo_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageInfo_struct;
#define TC_Evolution_Mail_MessageInfo ((CORBA_TypeCode)&TC_Evolution_Mail_MessageInfo_struct)
#endif
#define Evolution_Mail_MessageInfo__alloc() ((Evolution_Mail_MessageInfo *)ORBit_small_alloc (TC_Evolution_Mail_MessageInfo))
#define Evolution_Mail_MessageInfo__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_MessageInfo,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_MessageInfo)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_MessageInfo 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfo_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_MessageInfo_defined)
#define _CORBA_sequence_Evolution_Mail_MessageInfo_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_MessageInfo* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_MessageInfo;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_MessageInfo_struct;
#define TC_CORBA_sequence_Evolution_Mail_MessageInfo ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_MessageInfo_struct)
#endif
#define CORBA_sequence_Evolution_Mail_MessageInfo__alloc() ((CORBA_sequence_Evolution_Mail_MessageInfo *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_MessageInfo))
#define CORBA_sequence_Evolution_Mail_MessageInfo__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_MessageInfo,(m),(d))
#define CORBA_sequence_Evolution_Mail_MessageInfo_allocbuf(l) ((Evolution_Mail_MessageInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_MessageInfo, (l)))
#define CORBA_sequence_Evolution_Mail_MessageInfo_allocbuf(l) ((Evolution_Mail_MessageInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_MessageInfo, (l)))
#endif
#if !defined(_Evolution_Mail_MessageInfos_defined)
#define _Evolution_Mail_MessageInfos_defined 1
typedef CORBA_sequence_Evolution_Mail_MessageInfo Evolution_Mail_MessageInfos;
#define Evolution_Mail_MessageInfos_marshal(x,y,z) CORBA_sequence_Evolution_Mail_MessageInfo_marshal((x),(y),(z))
#define Evolution_Mail_MessageInfos_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_MessageInfo_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_MessageInfos_0)
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_0 'E'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_1 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_2 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_3 'l'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_4 'u'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_5 't'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_6 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_7 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_8 'n'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_9 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_10 'D'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_11 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_12 't'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_13 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_14 'S'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_15 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_16 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_17 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_18 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_19 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_20 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_21 'M'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_22 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_23 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageInfos_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageInfos_struct;
#define TC_Evolution_Mail_MessageInfos ((CORBA_TypeCode)&TC_Evolution_Mail_MessageInfos_struct)
#endif
#define Evolution_Mail_MessageInfos__alloc() ((Evolution_Mail_MessageInfos *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_MessageInfo))
#define Evolution_Mail_MessageInfos__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_MessageInfo,(m),(d))
#define Evolution_Mail_MessageInfos_allocbuf(l) ((Evolution_Mail_MessageInfo*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_MessageInfo, (l)))
#endif
#if !defined(_Evolution_Mail_MessageInfoSet_defined)
#define _Evolution_Mail_MessageInfoSet_defined 1
typedef struct Evolution_Mail_MessageInfoSet_type Evolution_Mail_MessageInfoSet;
struct Evolution_Mail_MessageInfoSet_type {
CORBA_string uid;
CORBA_long flagSet;
CORBA_long flagMask;
Evolution_Mail_UserFlags userFlagSet;
Evolution_Mail_UserFlags userFlagUnset;
Evolution_Mail_UserTags userTags;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_MessageInfoSet_0)
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_0 'E'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_1 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_2 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_3 'l'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_4 'u'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_5 't'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_6 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_7 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_8 'n'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_9 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_10 'D'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_11 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_12 't'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_13 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_14 'S'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_15 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_16 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_17 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_18 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_19 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_20 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_21 'M'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_22 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_23 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSet_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageInfoSet_struct;
#define TC_Evolution_Mail_MessageInfoSet ((CORBA_TypeCode)&TC_Evolution_Mail_MessageInfoSet_struct)
#endif
#define Evolution_Mail_MessageInfoSet__alloc() ((Evolution_Mail_MessageInfoSet *)ORBit_small_alloc (TC_Evolution_Mail_MessageInfoSet))
#define Evolution_Mail_MessageInfoSet__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_MessageInfoSet,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_MessageInfoSet)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_MessageInfoSet 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_MessageInfoSet_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_MessageInfoSet_defined)
#define _CORBA_sequence_Evolution_Mail_MessageInfoSet_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_MessageInfoSet* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_MessageInfoSet;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_struct;
#define TC_CORBA_sequence_Evolution_Mail_MessageInfoSet ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_struct)
#endif
#define CORBA_sequence_Evolution_Mail_MessageInfoSet__alloc() ((CORBA_sequence_Evolution_Mail_MessageInfoSet *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_MessageInfoSet))
#define CORBA_sequence_Evolution_Mail_MessageInfoSet__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_MessageInfoSet,(m),(d))
#define CORBA_sequence_Evolution_Mail_MessageInfoSet_allocbuf(l) ((Evolution_Mail_MessageInfoSet*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_MessageInfoSet, (l)))
#define CORBA_sequence_Evolution_Mail_MessageInfoSet_allocbuf(l) ((Evolution_Mail_MessageInfoSet*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_MessageInfoSet, (l)))
#endif
#if !defined(_Evolution_Mail_MessageInfoSets_defined)
#define _Evolution_Mail_MessageInfoSets_defined 1
typedef CORBA_sequence_Evolution_Mail_MessageInfoSet Evolution_Mail_MessageInfoSets;
#define Evolution_Mail_MessageInfoSets_marshal(x,y,z) CORBA_sequence_Evolution_Mail_MessageInfoSet_marshal((x),(y),(z))
#define Evolution_Mail_MessageInfoSets_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_MessageInfoSet_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_MessageInfoSets_0)
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_0 'E'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_1 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_2 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_3 'l'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_4 'u'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_5 't'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_6 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_7 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_8 'n'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_9 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_10 'D'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_11 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_12 't'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_13 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_14 'S'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_15 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_16 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_17 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_18 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_19 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_20 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_21 'M'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_22 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_23 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageInfoSets_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageInfoSets_struct;
#define TC_Evolution_Mail_MessageInfoSets ((CORBA_TypeCode)&TC_Evolution_Mail_MessageInfoSets_struct)
#endif
#define Evolution_Mail_MessageInfoSets__alloc() ((Evolution_Mail_MessageInfoSets *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_MessageInfoSet))
#define Evolution_Mail_MessageInfoSets__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_MessageInfoSet,(m),(d))
#define Evolution_Mail_MessageInfoSets_allocbuf(l) ((Evolution_Mail_MessageInfoSet*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_MessageInfoSet, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_octet)
#define ORBIT_DECL_CORBA_sequence_CORBA_octet 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_0 'E'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_10 'D'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_12 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_13 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_14 'S'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_15 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_16 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_17 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_18 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_19 'r'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_20 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_21 'M'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_22 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_23 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_octet_24 'l'
#if !defined(_CORBA_sequence_CORBA_octet_defined)
#define _CORBA_sequence_CORBA_octet_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_octet* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_octet;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_octet_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_0 'E'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_10 'D'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_12 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_13 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_14 'S'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_15 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_16 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_17 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_18 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_19 'r'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_20 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_21 'M'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_22 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_23 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_octet_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_octet_struct;
#define TC_CORBA_sequence_CORBA_octet ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_octet_struct)
#endif
#define CORBA_sequence_CORBA_octet__alloc() ((CORBA_sequence_CORBA_octet *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_octet))
#define CORBA_sequence_CORBA_octet__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_octet,(m),(d))
#define CORBA_sequence_CORBA_octet_allocbuf(l) ((CORBA_octet*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_octet, (l)))
#define CORBA_sequence_CORBA_octet_allocbuf(l) ((CORBA_octet*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_octet, (l)))
#endif
#if !defined(_Evolution_Mail_Buffer_defined)
#define _Evolution_Mail_Buffer_defined 1
typedef CORBA_sequence_CORBA_octet Evolution_Mail_Buffer;
#define Evolution_Mail_Buffer_marshal(x,y,z) CORBA_sequence_CORBA_octet_marshal((x),(y),(z))
#define Evolution_Mail_Buffer_demarshal(x,y,z,i) CORBA_sequence_CORBA_octet_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_Buffer_0)
#define TC_IMPL_TC_Evolution_Mail_Buffer_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Buffer_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Buffer_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Buffer_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Buffer_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Buffer_5 't'
#define TC_IMPL_TC_Evolution_Mail_Buffer_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Buffer_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Buffer_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Buffer_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Buffer_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Buffer_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Buffer_12 't'
#define TC_IMPL_TC_Evolution_Mail_Buffer_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Buffer_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Buffer_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Buffer_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Buffer_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Buffer_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Buffer_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Buffer_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Buffer_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Buffer_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Buffer_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Buffer_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Buffer_struct;
#define TC_Evolution_Mail_Buffer ((CORBA_TypeCode)&TC_Evolution_Mail_Buffer_struct)
#endif
#define Evolution_Mail_Buffer__alloc() ((Evolution_Mail_Buffer *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_octet))
#define Evolution_Mail_Buffer__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_octet,(m),(d))
#define Evolution_Mail_Buffer_allocbuf(l) ((CORBA_octet*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_octet, (l)))
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_MessageStream) && !defined(_Evolution_Mail_MessageStream_defined)
#define ORBIT_DECL_Evolution_Mail_MessageStream 1
#define _Evolution_Mail_MessageStream_defined 1
#define Evolution_Mail_MessageStream__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_MessageStream;
extern CORBA_unsigned_long Evolution_Mail_MessageStream__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_MessageStream_0)
#define TC_IMPL_TC_Evolution_Mail_MessageStream_0 'E'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_1 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_2 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_3 'l'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_4 'u'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_5 't'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_6 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_7 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_8 'n'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_9 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_10 'D'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_11 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_12 't'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_13 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_14 'S'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_15 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_16 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_17 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_18 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_19 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_20 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_21 'M'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_22 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_23 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageStream_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageStream_struct;
#define TC_Evolution_Mail_MessageStream ((CORBA_TypeCode)&TC_Evolution_Mail_MessageStream_struct)
#endif
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_MessageIterator) && !defined(_Evolution_Mail_MessageIterator_defined)
#define ORBIT_DECL_Evolution_Mail_MessageIterator 1
#define _Evolution_Mail_MessageIterator_defined 1
#define Evolution_Mail_MessageIterator__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_MessageIterator;
extern CORBA_unsigned_long Evolution_Mail_MessageIterator__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_MessageIterator_0)
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_0 'E'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_1 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_2 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_3 'l'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_4 'u'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_5 't'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_6 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_7 'o'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_8 'n'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_9 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_10 'D'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_11 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_12 't'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_13 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_14 'S'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_15 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_16 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_17 'v'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_18 'e'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_19 'r'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_20 '_'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_21 'M'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_22 'a'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_23 'i'
#define TC_IMPL_TC_Evolution_Mail_MessageIterator_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageIterator_struct;
#define TC_Evolution_Mail_MessageIterator ((CORBA_TypeCode)&TC_Evolution_Mail_MessageIterator_struct)
#endif
#endif
#if !defined(_Evolution_Mail_ChangeType_defined)
#define _Evolution_Mail_ChangeType_defined 1
typedef enum {
  Evolution_Mail_ADDED,
  Evolution_Mail_REMOVED,
  Evolution_Mail_CHANGED
} Evolution_Mail_ChangeType;
#if !defined(TC_IMPL_TC_Evolution_Mail_ChangeType_0)
#define TC_IMPL_TC_Evolution_Mail_ChangeType_0 'E'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_1 'v'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_2 'o'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_3 'l'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_4 'u'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_5 't'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_6 'i'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_7 'o'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_8 'n'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_9 '_'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_10 'D'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_11 'a'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_12 't'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_13 'a'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_14 'S'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_15 'e'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_16 'r'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_17 'v'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_18 'e'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_19 'r'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_20 '_'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_21 'M'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_22 'a'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_23 'i'
#define TC_IMPL_TC_Evolution_Mail_ChangeType_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_ChangeType_struct;
#define TC_Evolution_Mail_ChangeType ((CORBA_TypeCode)&TC_Evolution_Mail_ChangeType_struct)
#endif
#endif
#if !defined(_Evolution_Mail_SessionChange_defined)
#define _Evolution_Mail_SessionChange_defined 1
typedef struct Evolution_Mail_SessionChange_type Evolution_Mail_SessionChange;
struct Evolution_Mail_SessionChange_type {
Evolution_Mail_ChangeType type;
Evolution_Mail_StoreInfos stores;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_SessionChange_0)
#define TC_IMPL_TC_Evolution_Mail_SessionChange_0 'E'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_1 'v'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_2 'o'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_3 'l'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_4 'u'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_5 't'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_6 'i'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_7 'o'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_8 'n'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_9 '_'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_10 'D'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_11 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_12 't'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_13 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_14 'S'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_15 'e'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_16 'r'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_17 'v'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_18 'e'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_19 'r'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_20 '_'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_21 'M'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_22 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_23 'i'
#define TC_IMPL_TC_Evolution_Mail_SessionChange_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_SessionChange_struct;
#define TC_Evolution_Mail_SessionChange ((CORBA_TypeCode)&TC_Evolution_Mail_SessionChange_struct)
#endif
#define Evolution_Mail_SessionChange__alloc() ((Evolution_Mail_SessionChange *)ORBit_small_alloc (TC_Evolution_Mail_SessionChange))
#define Evolution_Mail_SessionChange__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_SessionChange,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_SessionChange)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_SessionChange 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_SessionChange_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_SessionChange_defined)
#define _CORBA_sequence_Evolution_Mail_SessionChange_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_SessionChange* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_SessionChange;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_SessionChange_struct;
#define TC_CORBA_sequence_Evolution_Mail_SessionChange ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_SessionChange_struct)
#endif
#define CORBA_sequence_Evolution_Mail_SessionChange__alloc() ((CORBA_sequence_Evolution_Mail_SessionChange *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_SessionChange))
#define CORBA_sequence_Evolution_Mail_SessionChange__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_SessionChange,(m),(d))
#define CORBA_sequence_Evolution_Mail_SessionChange_allocbuf(l) ((Evolution_Mail_SessionChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_SessionChange, (l)))
#define CORBA_sequence_Evolution_Mail_SessionChange_allocbuf(l) ((Evolution_Mail_SessionChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_SessionChange, (l)))
#endif
#if !defined(_Evolution_Mail_SessionChanges_defined)
#define _Evolution_Mail_SessionChanges_defined 1
typedef CORBA_sequence_Evolution_Mail_SessionChange Evolution_Mail_SessionChanges;
#define Evolution_Mail_SessionChanges_marshal(x,y,z) CORBA_sequence_Evolution_Mail_SessionChange_marshal((x),(y),(z))
#define Evolution_Mail_SessionChanges_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_SessionChange_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_SessionChanges_0)
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_0 'E'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_1 'v'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_2 'o'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_3 'l'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_4 'u'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_5 't'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_6 'i'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_7 'o'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_8 'n'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_9 '_'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_10 'D'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_11 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_12 't'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_13 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_14 'S'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_15 'e'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_16 'r'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_17 'v'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_18 'e'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_19 'r'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_20 '_'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_21 'M'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_22 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_23 'i'
#define TC_IMPL_TC_Evolution_Mail_SessionChanges_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_SessionChanges_struct;
#define TC_Evolution_Mail_SessionChanges ((CORBA_TypeCode)&TC_Evolution_Mail_SessionChanges_struct)
#endif
#define Evolution_Mail_SessionChanges__alloc() ((Evolution_Mail_SessionChanges *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_SessionChange))
#define Evolution_Mail_SessionChanges__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_SessionChange,(m),(d))
#define Evolution_Mail_SessionChanges_allocbuf(l) ((Evolution_Mail_SessionChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_SessionChange, (l)))
#endif
#if !defined(_Evolution_Mail_StoreChange_defined)
#define _Evolution_Mail_StoreChange_defined 1
typedef struct Evolution_Mail_StoreChange_type Evolution_Mail_StoreChange;
struct Evolution_Mail_StoreChange_type {
Evolution_Mail_ChangeType type;
Evolution_Mail_FolderInfos folders;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_StoreChange_0)
#define TC_IMPL_TC_Evolution_Mail_StoreChange_0 'E'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_1 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_2 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_3 'l'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_4 'u'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_5 't'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_6 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_7 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_8 'n'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_9 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_10 'D'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_11 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_12 't'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_13 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_14 'S'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_15 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_16 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_17 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_18 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_19 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_20 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_21 'M'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_22 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_23 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreChange_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreChange_struct;
#define TC_Evolution_Mail_StoreChange ((CORBA_TypeCode)&TC_Evolution_Mail_StoreChange_struct)
#endif
#define Evolution_Mail_StoreChange__alloc() ((Evolution_Mail_StoreChange *)ORBit_small_alloc (TC_Evolution_Mail_StoreChange))
#define Evolution_Mail_StoreChange__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_StoreChange,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_StoreChange)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_StoreChange 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_StoreChange_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_StoreChange_defined)
#define _CORBA_sequence_Evolution_Mail_StoreChange_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_StoreChange* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_StoreChange;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_StoreChange_struct;
#define TC_CORBA_sequence_Evolution_Mail_StoreChange ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_StoreChange_struct)
#endif
#define CORBA_sequence_Evolution_Mail_StoreChange__alloc() ((CORBA_sequence_Evolution_Mail_StoreChange *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_StoreChange))
#define CORBA_sequence_Evolution_Mail_StoreChange__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_StoreChange,(m),(d))
#define CORBA_sequence_Evolution_Mail_StoreChange_allocbuf(l) ((Evolution_Mail_StoreChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_StoreChange, (l)))
#define CORBA_sequence_Evolution_Mail_StoreChange_allocbuf(l) ((Evolution_Mail_StoreChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_StoreChange, (l)))
#endif
#if !defined(_Evolution_Mail_StoreChanges_defined)
#define _Evolution_Mail_StoreChanges_defined 1
typedef CORBA_sequence_Evolution_Mail_StoreChange Evolution_Mail_StoreChanges;
#define Evolution_Mail_StoreChanges_marshal(x,y,z) CORBA_sequence_Evolution_Mail_StoreChange_marshal((x),(y),(z))
#define Evolution_Mail_StoreChanges_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_StoreChange_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_StoreChanges_0)
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_0 'E'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_1 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_2 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_3 'l'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_4 'u'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_5 't'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_6 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_7 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_8 'n'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_9 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_10 'D'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_11 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_12 't'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_13 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_14 'S'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_15 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_16 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_17 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_18 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_19 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_20 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_21 'M'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_22 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_23 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreChanges_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreChanges_struct;
#define TC_Evolution_Mail_StoreChanges ((CORBA_TypeCode)&TC_Evolution_Mail_StoreChanges_struct)
#endif
#define Evolution_Mail_StoreChanges__alloc() ((Evolution_Mail_StoreChanges *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_StoreChange))
#define Evolution_Mail_StoreChanges__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_StoreChange,(m),(d))
#define Evolution_Mail_StoreChanges_allocbuf(l) ((Evolution_Mail_StoreChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_StoreChange, (l)))
#endif
#if !defined(_Evolution_Mail_FolderChange_defined)
#define _Evolution_Mail_FolderChange_defined 1
typedef struct Evolution_Mail_FolderChange_type Evolution_Mail_FolderChange;
struct Evolution_Mail_FolderChange_type {
Evolution_Mail_ChangeType type;
Evolution_Mail_MessageInfos messages;
};

#if !defined(TC_IMPL_TC_Evolution_Mail_FolderChange_0)
#define TC_IMPL_TC_Evolution_Mail_FolderChange_0 'E'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_1 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_2 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_3 'l'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_4 'u'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_5 't'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_6 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_7 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_8 'n'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_9 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_10 'D'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_11 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_12 't'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_13 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_14 'S'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_15 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_16 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_17 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_18 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_19 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_20 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_21 'M'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_22 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_23 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderChange_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderChange_struct;
#define TC_Evolution_Mail_FolderChange ((CORBA_TypeCode)&TC_Evolution_Mail_FolderChange_struct)
#endif
#define Evolution_Mail_FolderChange__alloc() ((Evolution_Mail_FolderChange *)ORBit_small_alloc (TC_Evolution_Mail_FolderChange))
#define Evolution_Mail_FolderChange__freekids(m,d) ORBit_small_freekids (TC_Evolution_Mail_FolderChange,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_Evolution_Mail_FolderChange)
#define ORBIT_DECL_CORBA_sequence_Evolution_Mail_FolderChange 1
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_0 'E'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_1 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_2 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_3 'l'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_4 'u'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_5 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_6 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_7 'o'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_8 'n'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_9 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_10 'D'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_11 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_12 't'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_13 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_14 'S'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_15 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_16 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_17 'v'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_18 'e'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_19 'r'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_20 '_'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_21 'M'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_22 'a'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_23 'i'
#define ORBIT_IMPL_CORBA_sequence_Evolution_Mail_FolderChange_24 'l'
#if !defined(_CORBA_sequence_Evolution_Mail_FolderChange_defined)
#define _CORBA_sequence_Evolution_Mail_FolderChange_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; Evolution_Mail_FolderChange* _buffer; CORBA_boolean _release; } CORBA_sequence_Evolution_Mail_FolderChange;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_0)
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_0 'E'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_1 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_2 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_3 'l'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_4 'u'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_5 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_6 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_7 'o'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_8 'n'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_9 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_10 'D'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_11 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_12 't'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_13 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_14 'S'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_15 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_16 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_17 'v'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_18 'e'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_19 'r'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_20 '_'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_21 'M'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_22 'a'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_23 'i'
#define TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_FolderChange_struct;
#define TC_CORBA_sequence_Evolution_Mail_FolderChange ((CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_FolderChange_struct)
#endif
#define CORBA_sequence_Evolution_Mail_FolderChange__alloc() ((CORBA_sequence_Evolution_Mail_FolderChange *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_FolderChange))
#define CORBA_sequence_Evolution_Mail_FolderChange__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_FolderChange,(m),(d))
#define CORBA_sequence_Evolution_Mail_FolderChange_allocbuf(l) ((Evolution_Mail_FolderChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_FolderChange, (l)))
#define CORBA_sequence_Evolution_Mail_FolderChange_allocbuf(l) ((Evolution_Mail_FolderChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_FolderChange, (l)))
#endif
#if !defined(_Evolution_Mail_FolderChanges_defined)
#define _Evolution_Mail_FolderChanges_defined 1
typedef CORBA_sequence_Evolution_Mail_FolderChange Evolution_Mail_FolderChanges;
#define Evolution_Mail_FolderChanges_marshal(x,y,z) CORBA_sequence_Evolution_Mail_FolderChange_marshal((x),(y),(z))
#define Evolution_Mail_FolderChanges_demarshal(x,y,z,i) CORBA_sequence_Evolution_Mail_FolderChange_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_Evolution_Mail_FolderChanges_0)
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_0 'E'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_1 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_2 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_3 'l'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_4 'u'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_5 't'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_6 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_7 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_8 'n'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_9 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_10 'D'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_11 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_12 't'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_13 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_14 'S'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_15 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_16 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_17 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_18 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_19 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_20 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_21 'M'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_22 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_23 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderChanges_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderChanges_struct;
#define TC_Evolution_Mail_FolderChanges ((CORBA_TypeCode)&TC_Evolution_Mail_FolderChanges_struct)
#endif
#define Evolution_Mail_FolderChanges__alloc() ((Evolution_Mail_FolderChanges *)ORBit_small_alloc (TC_CORBA_sequence_Evolution_Mail_FolderChange))
#define Evolution_Mail_FolderChanges__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_Evolution_Mail_FolderChange,(m),(d))
#define Evolution_Mail_FolderChanges_allocbuf(l) ((Evolution_Mail_FolderChange*)ORBit_small_allocbuf (TC_CORBA_sequence_Evolution_Mail_FolderChange, (l)))
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_SessionListener) && !defined(_Evolution_Mail_SessionListener_defined)
#define ORBIT_DECL_Evolution_Mail_SessionListener 1
#define _Evolution_Mail_SessionListener_defined 1
#define Evolution_Mail_SessionListener__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_SessionListener;
extern CORBA_unsigned_long Evolution_Mail_SessionListener__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_SessionListener_0)
#define TC_IMPL_TC_Evolution_Mail_SessionListener_0 'E'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_1 'v'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_2 'o'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_3 'l'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_4 'u'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_5 't'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_6 'i'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_7 'o'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_8 'n'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_9 '_'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_10 'D'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_11 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_12 't'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_13 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_14 'S'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_15 'e'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_16 'r'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_17 'v'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_18 'e'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_19 'r'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_20 '_'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_21 'M'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_22 'a'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_23 'i'
#define TC_IMPL_TC_Evolution_Mail_SessionListener_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_SessionListener_struct;
#define TC_Evolution_Mail_SessionListener ((CORBA_TypeCode)&TC_Evolution_Mail_SessionListener_struct)
#endif
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_StoreListener) && !defined(_Evolution_Mail_StoreListener_defined)
#define ORBIT_DECL_Evolution_Mail_StoreListener 1
#define _Evolution_Mail_StoreListener_defined 1
#define Evolution_Mail_StoreListener__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_StoreListener;
extern CORBA_unsigned_long Evolution_Mail_StoreListener__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_StoreListener_0)
#define TC_IMPL_TC_Evolution_Mail_StoreListener_0 'E'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_1 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_2 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_3 'l'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_4 'u'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_5 't'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_6 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_7 'o'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_8 'n'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_9 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_10 'D'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_11 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_12 't'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_13 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_14 'S'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_15 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_16 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_17 'v'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_18 'e'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_19 'r'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_20 '_'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_21 'M'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_22 'a'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_23 'i'
#define TC_IMPL_TC_Evolution_Mail_StoreListener_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreListener_struct;
#define TC_Evolution_Mail_StoreListener ((CORBA_TypeCode)&TC_Evolution_Mail_StoreListener_struct)
#endif
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_FolderListener) && !defined(_Evolution_Mail_FolderListener_defined)
#define ORBIT_DECL_Evolution_Mail_FolderListener 1
#define _Evolution_Mail_FolderListener_defined 1
#define Evolution_Mail_FolderListener__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_FolderListener;
extern CORBA_unsigned_long Evolution_Mail_FolderListener__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_FolderListener_0)
#define TC_IMPL_TC_Evolution_Mail_FolderListener_0 'E'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_1 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_2 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_3 'l'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_4 'u'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_5 't'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_6 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_7 'o'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_8 'n'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_9 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_10 'D'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_11 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_12 't'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_13 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_14 'S'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_15 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_16 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_17 'v'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_18 'e'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_19 'r'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_20 '_'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_21 'M'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_22 'a'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_23 'i'
#define TC_IMPL_TC_Evolution_Mail_FolderListener_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderListener_struct;
#define TC_Evolution_Mail_FolderListener ((CORBA_TypeCode)&TC_Evolution_Mail_FolderListener_struct)
#endif
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_Session) && !defined(_Evolution_Mail_Session_defined)
#define ORBIT_DECL_Evolution_Mail_Session 1
#define _Evolution_Mail_Session_defined 1
#define Evolution_Mail_Session__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_Session;
extern CORBA_unsigned_long Evolution_Mail_Session__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_Session_0)
#define TC_IMPL_TC_Evolution_Mail_Session_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Session_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Session_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Session_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Session_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Session_5 't'
#define TC_IMPL_TC_Evolution_Mail_Session_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Session_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Session_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Session_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Session_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Session_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Session_12 't'
#define TC_IMPL_TC_Evolution_Mail_Session_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Session_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Session_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Session_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Session_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Session_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Session_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Session_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Session_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Session_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Session_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Session_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Session_struct;
#define TC_Evolution_Mail_Session ((CORBA_TypeCode)&TC_Evolution_Mail_Session_struct)
#endif
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_Store) && !defined(_Evolution_Mail_Store_defined)
#define ORBIT_DECL_Evolution_Mail_Store 1
#define _Evolution_Mail_Store_defined 1
#define Evolution_Mail_Store__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_Store;
extern CORBA_unsigned_long Evolution_Mail_Store__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_Store_0)
#define TC_IMPL_TC_Evolution_Mail_Store_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Store_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Store_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Store_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Store_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Store_5 't'
#define TC_IMPL_TC_Evolution_Mail_Store_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Store_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Store_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Store_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Store_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Store_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Store_12 't'
#define TC_IMPL_TC_Evolution_Mail_Store_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Store_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Store_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Store_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Store_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Store_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Store_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Store_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Store_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Store_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Store_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Store_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Store_struct;
#define TC_Evolution_Mail_Store ((CORBA_TypeCode)&TC_Evolution_Mail_Store_struct)
#endif
#endif
#if !defined(ORBIT_DECL_Evolution_Mail_Folder) && !defined(_Evolution_Mail_Folder_defined)
#define ORBIT_DECL_Evolution_Mail_Folder 1
#define _Evolution_Mail_Folder_defined 1
#define Evolution_Mail_Folder__freekids CORBA_Object__freekids
typedef CORBA_Object Evolution_Mail_Folder;
extern CORBA_unsigned_long Evolution_Mail_Folder__classid;
#if !defined(TC_IMPL_TC_Evolution_Mail_Folder_0)
#define TC_IMPL_TC_Evolution_Mail_Folder_0 'E'
#define TC_IMPL_TC_Evolution_Mail_Folder_1 'v'
#define TC_IMPL_TC_Evolution_Mail_Folder_2 'o'
#define TC_IMPL_TC_Evolution_Mail_Folder_3 'l'
#define TC_IMPL_TC_Evolution_Mail_Folder_4 'u'
#define TC_IMPL_TC_Evolution_Mail_Folder_5 't'
#define TC_IMPL_TC_Evolution_Mail_Folder_6 'i'
#define TC_IMPL_TC_Evolution_Mail_Folder_7 'o'
#define TC_IMPL_TC_Evolution_Mail_Folder_8 'n'
#define TC_IMPL_TC_Evolution_Mail_Folder_9 '_'
#define TC_IMPL_TC_Evolution_Mail_Folder_10 'D'
#define TC_IMPL_TC_Evolution_Mail_Folder_11 'a'
#define TC_IMPL_TC_Evolution_Mail_Folder_12 't'
#define TC_IMPL_TC_Evolution_Mail_Folder_13 'a'
#define TC_IMPL_TC_Evolution_Mail_Folder_14 'S'
#define TC_IMPL_TC_Evolution_Mail_Folder_15 'e'
#define TC_IMPL_TC_Evolution_Mail_Folder_16 'r'
#define TC_IMPL_TC_Evolution_Mail_Folder_17 'v'
#define TC_IMPL_TC_Evolution_Mail_Folder_18 'e'
#define TC_IMPL_TC_Evolution_Mail_Folder_19 'r'
#define TC_IMPL_TC_Evolution_Mail_Folder_20 '_'
#define TC_IMPL_TC_Evolution_Mail_Folder_21 'M'
#define TC_IMPL_TC_Evolution_Mail_Folder_22 'a'
#define TC_IMPL_TC_Evolution_Mail_Folder_23 'i'
#define TC_IMPL_TC_Evolution_Mail_Folder_24 'l'
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Folder_struct;
#define TC_Evolution_Mail_Folder ((CORBA_TypeCode)&TC_Evolution_Mail_Folder_struct)
#endif
#endif

/** POA structures **/
#ifndef _defined_POA_Evolution_Mail_MessageStream
#define _defined_POA_Evolution_Mail_MessageStream 1
typedef struct {
  void *_private;
Evolution_Mail_Buffer* (*next)(PortableServer_Servant _servant, const CORBA_long size, CORBA_Environment *ev);
void (*dispose)(PortableServer_Servant _servant, CORBA_Environment *ev);
} POA_Evolution_Mail_MessageStream__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_Evolution_Mail_MessageStream__epv *Evolution_Mail_MessageStream_epv;
} POA_Evolution_Mail_MessageStream__vepv;
typedef struct {
  void *_private;
  POA_Evolution_Mail_MessageStream__vepv *vepv;
} POA_Evolution_Mail_MessageStream;
extern void POA_Evolution_Mail_MessageStream__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_Evolution_Mail_MessageStream__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_Evolution_Mail_MessageStream */
#ifndef _defined_POA_Evolution_Mail_MessageIterator
#define _defined_POA_Evolution_Mail_MessageIterator 1
typedef struct {
  void *_private;
Evolution_Mail_MessageInfos* (*next)(PortableServer_Servant _servant, const CORBA_long limit, CORBA_Environment *ev);
void (*dispose)(PortableServer_Servant _servant, CORBA_Environment *ev);
} POA_Evolution_Mail_MessageIterator__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_Evolution_Mail_MessageIterator__epv *Evolution_Mail_MessageIterator_epv;
} POA_Evolution_Mail_MessageIterator__vepv;
typedef struct {
  void *_private;
  POA_Evolution_Mail_MessageIterator__vepv *vepv;
} POA_Evolution_Mail_MessageIterator;
extern void POA_Evolution_Mail_MessageIterator__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_Evolution_Mail_MessageIterator__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_Evolution_Mail_MessageIterator */
#ifndef _defined_POA_Evolution_Mail_SessionListener
#define _defined_POA_Evolution_Mail_SessionListener 1
typedef struct {
  void *_private;
void (*changed)(PortableServer_Servant _servant, const Evolution_Mail_Session session, const Evolution_Mail_SessionChanges* changes, CORBA_Environment *ev);
void (*shutdown)(PortableServer_Servant _servant, const Evolution_Mail_Session session, CORBA_Environment *ev);
} POA_Evolution_Mail_SessionListener__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_Evolution_Mail_SessionListener__epv *Evolution_Mail_SessionListener_epv;
} POA_Evolution_Mail_SessionListener__vepv;
typedef struct {
  void *_private;
  POA_Evolution_Mail_SessionListener__vepv *vepv;
} POA_Evolution_Mail_SessionListener;
extern void POA_Evolution_Mail_SessionListener__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_Evolution_Mail_SessionListener__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_Evolution_Mail_SessionListener */
#ifndef _defined_POA_Evolution_Mail_StoreListener
#define _defined_POA_Evolution_Mail_StoreListener 1
typedef struct {
  void *_private;
void (*changed)(PortableServer_Servant _servant, const Evolution_Mail_Store store, const Evolution_Mail_StoreChanges* changes, CORBA_Environment *ev);
} POA_Evolution_Mail_StoreListener__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_Evolution_Mail_StoreListener__epv *Evolution_Mail_StoreListener_epv;
} POA_Evolution_Mail_StoreListener__vepv;
typedef struct {
  void *_private;
  POA_Evolution_Mail_StoreListener__vepv *vepv;
} POA_Evolution_Mail_StoreListener;
extern void POA_Evolution_Mail_StoreListener__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_Evolution_Mail_StoreListener__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_Evolution_Mail_StoreListener */
#ifndef _defined_POA_Evolution_Mail_FolderListener
#define _defined_POA_Evolution_Mail_FolderListener 1
typedef struct {
  void *_private;
void (*changed)(PortableServer_Servant _servant, const Evolution_Mail_Folder folder, const Evolution_Mail_FolderChanges* changes, CORBA_Environment *ev);
} POA_Evolution_Mail_FolderListener__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_Evolution_Mail_FolderListener__epv *Evolution_Mail_FolderListener_epv;
} POA_Evolution_Mail_FolderListener__vepv;
typedef struct {
  void *_private;
  POA_Evolution_Mail_FolderListener__vepv *vepv;
} POA_Evolution_Mail_FolderListener;
extern void POA_Evolution_Mail_FolderListener__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_Evolution_Mail_FolderListener__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_Evolution_Mail_FolderListener */
#ifndef _defined_POA_Evolution_Mail_Session
#define _defined_POA_Evolution_Mail_Session 1
typedef struct {
  void *_private;
CORBA_boolean (*getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev);
Evolution_Mail_StoreInfos* (*getStores)(PortableServer_Servant _servant, const CORBA_char * pattern, const Evolution_Mail_StoreListener listener, CORBA_Environment *ev);
void (*addListener)(PortableServer_Servant _servant, const Evolution_Mail_SessionListener listener, CORBA_Environment *ev);
void (*removeListener)(PortableServer_Servant _servant, const Evolution_Mail_SessionListener listener, CORBA_Environment *ev);
} POA_Evolution_Mail_Session__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_Evolution_Mail_Session__epv *Evolution_Mail_Session_epv;
} POA_Evolution_Mail_Session__vepv;
typedef struct {
  void *_private;
  POA_Evolution_Mail_Session__vepv *vepv;
} POA_Evolution_Mail_Session;
extern void POA_Evolution_Mail_Session__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_Evolution_Mail_Session__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_Evolution_Mail_Session */
#ifndef _defined_POA_Evolution_Mail_Store
#define _defined_POA_Evolution_Mail_Store 1
typedef struct {
  void *_private;
CORBA_boolean (*getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev);
Evolution_Mail_FolderInfos* (*getFolders)(PortableServer_Servant _servant, const CORBA_char * pattern, const Evolution_Mail_FolderListener listener, CORBA_Environment *ev);
void (*sendMessage)(PortableServer_Servant _servant, const Evolution_Mail_MessageStream msg, CORBA_Environment *ev);
} POA_Evolution_Mail_Store__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_Evolution_Mail_Store__epv *Evolution_Mail_Store_epv;
} POA_Evolution_Mail_Store__vepv;
typedef struct {
  void *_private;
  POA_Evolution_Mail_Store__vepv *vepv;
} POA_Evolution_Mail_Store;
extern void POA_Evolution_Mail_Store__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_Evolution_Mail_Store__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_Evolution_Mail_Store */
#ifndef _defined_POA_Evolution_Mail_Folder
#define _defined_POA_Evolution_Mail_Folder 1
typedef struct {
  void *_private;
CORBA_boolean (*getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev);
Evolution_Mail_MessageIterator (*getMessages)(PortableServer_Servant _servant, const CORBA_char * pattern, CORBA_Environment *ev);
void (*changeMessages)(PortableServer_Servant _servant, const Evolution_Mail_MessageInfoSets* infos, CORBA_Environment *ev);
Evolution_Mail_MessageStream (*getMessage)(PortableServer_Servant _servant, const CORBA_char * uid, CORBA_Environment *ev);
void (*appendMessage)(PortableServer_Servant _servant, const Evolution_Mail_MessageInfoSet* info, const Evolution_Mail_MessageStream msg, CORBA_Environment *ev);
} POA_Evolution_Mail_Folder__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_Evolution_Mail_Folder__epv *Evolution_Mail_Folder_epv;
} POA_Evolution_Mail_Folder__vepv;
typedef struct {
  void *_private;
  POA_Evolution_Mail_Folder__vepv *vepv;
} POA_Evolution_Mail_Folder;
extern void POA_Evolution_Mail_Folder__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_Evolution_Mail_Folder__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_Evolution_Mail_Folder */

/** skel prototypes **/
void _ORBIT_skel_small_Evolution_Mail_MessageStream_next(POA_Evolution_Mail_MessageStream *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, Evolution_Mail_Buffer* (*_impl_next)(PortableServer_Servant _servant, const CORBA_long size, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_MessageStream_dispose(POA_Evolution_Mail_MessageStream *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_dispose)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_MessageIterator_next(POA_Evolution_Mail_MessageIterator *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, Evolution_Mail_MessageInfos* (*_impl_next)(PortableServer_Servant _servant, const CORBA_long limit, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_MessageIterator_dispose(POA_Evolution_Mail_MessageIterator *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_dispose)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_SessionListener_changed(POA_Evolution_Mail_SessionListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_changed)(PortableServer_Servant _servant, const Evolution_Mail_Session session, const Evolution_Mail_SessionChanges* changes, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_SessionListener_shutdown(POA_Evolution_Mail_SessionListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_shutdown)(PortableServer_Servant _servant, const Evolution_Mail_Session session, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_StoreListener_changed(POA_Evolution_Mail_StoreListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_changed)(PortableServer_Servant _servant, const Evolution_Mail_Store store, const Evolution_Mail_StoreChanges* changes, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_FolderListener_changed(POA_Evolution_Mail_FolderListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_changed)(PortableServer_Servant _servant, const Evolution_Mail_Folder folder, const Evolution_Mail_FolderChanges* changes, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Session_getProperties(POA_Evolution_Mail_Session *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, CORBA_boolean (*_impl_getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Session_getStores(POA_Evolution_Mail_Session *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, Evolution_Mail_StoreInfos* (*_impl_getStores)(PortableServer_Servant _servant, const CORBA_char * pattern, const Evolution_Mail_StoreListener listener, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Session_addListener(POA_Evolution_Mail_Session *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_addListener)(PortableServer_Servant _servant, const Evolution_Mail_SessionListener listener, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Session_removeListener(POA_Evolution_Mail_Session *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_removeListener)(PortableServer_Servant _servant, const Evolution_Mail_SessionListener listener, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Store_getProperties(POA_Evolution_Mail_Store *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, CORBA_boolean (*_impl_getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Store_getFolders(POA_Evolution_Mail_Store *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, Evolution_Mail_FolderInfos* (*_impl_getFolders)(PortableServer_Servant _servant, const CORBA_char * pattern, const Evolution_Mail_FolderListener listener, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Store_sendMessage(POA_Evolution_Mail_Store *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_sendMessage)(PortableServer_Servant _servant, const Evolution_Mail_MessageStream msg, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Folder_getProperties(POA_Evolution_Mail_Folder *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, CORBA_boolean (*_impl_getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Folder_getMessages(POA_Evolution_Mail_Folder *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, Evolution_Mail_MessageIterator (*_impl_getMessages)(PortableServer_Servant _servant, const CORBA_char * pattern, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Folder_changeMessages(POA_Evolution_Mail_Folder *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_changeMessages)(PortableServer_Servant _servant, const Evolution_Mail_MessageInfoSets* infos, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Folder_getMessage(POA_Evolution_Mail_Folder *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, Evolution_Mail_MessageStream (*_impl_getMessage)(PortableServer_Servant _servant, const CORBA_char * uid, CORBA_Environment *ev));
void _ORBIT_skel_small_Evolution_Mail_Folder_appendMessage(POA_Evolution_Mail_Folder *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_appendMessage)(PortableServer_Servant _servant, const Evolution_Mail_MessageInfoSet* info, const Evolution_Mail_MessageStream msg, CORBA_Environment *ev));

/** stub prototypes **/
#define Evolution_Mail_MessageStream_ref Bonobo_Unknown_ref
#define Evolution_Mail_MessageStream_unref Bonobo_Unknown_unref
#define Evolution_Mail_MessageStream_queryInterface Bonobo_Unknown_queryInterface
Evolution_Mail_Buffer* Evolution_Mail_MessageStream_next(Evolution_Mail_MessageStream _obj, const CORBA_long size, CORBA_Environment *ev);
void Evolution_Mail_MessageStream_dispose(Evolution_Mail_MessageStream _obj, CORBA_Environment *ev);
#define Evolution_Mail_MessageIterator_ref Bonobo_Unknown_ref
#define Evolution_Mail_MessageIterator_unref Bonobo_Unknown_unref
#define Evolution_Mail_MessageIterator_queryInterface Bonobo_Unknown_queryInterface
Evolution_Mail_MessageInfos* Evolution_Mail_MessageIterator_next(Evolution_Mail_MessageIterator _obj, const CORBA_long limit, CORBA_Environment *ev);
void Evolution_Mail_MessageIterator_dispose(Evolution_Mail_MessageIterator _obj, CORBA_Environment *ev);
#define Evolution_Mail_SessionListener_ref Bonobo_Unknown_ref
#define Evolution_Mail_SessionListener_unref Bonobo_Unknown_unref
#define Evolution_Mail_SessionListener_queryInterface Bonobo_Unknown_queryInterface
void Evolution_Mail_SessionListener_changed(Evolution_Mail_SessionListener _obj, const Evolution_Mail_Session session, const Evolution_Mail_SessionChanges* changes, CORBA_Environment *ev);
void Evolution_Mail_SessionListener_shutdown(Evolution_Mail_SessionListener _obj, const Evolution_Mail_Session session, CORBA_Environment *ev);
#define Evolution_Mail_StoreListener_ref Bonobo_Unknown_ref
#define Evolution_Mail_StoreListener_unref Bonobo_Unknown_unref
#define Evolution_Mail_StoreListener_queryInterface Bonobo_Unknown_queryInterface
void Evolution_Mail_StoreListener_changed(Evolution_Mail_StoreListener _obj, const Evolution_Mail_Store store, const Evolution_Mail_StoreChanges* changes, CORBA_Environment *ev);
#define Evolution_Mail_FolderListener_ref Bonobo_Unknown_ref
#define Evolution_Mail_FolderListener_unref Bonobo_Unknown_unref
#define Evolution_Mail_FolderListener_queryInterface Bonobo_Unknown_queryInterface
void Evolution_Mail_FolderListener_changed(Evolution_Mail_FolderListener _obj, const Evolution_Mail_Folder folder, const Evolution_Mail_FolderChanges* changes, CORBA_Environment *ev);
#define Evolution_Mail_Session_ref Bonobo_Unknown_ref
#define Evolution_Mail_Session_unref Bonobo_Unknown_unref
#define Evolution_Mail_Session_queryInterface Bonobo_Unknown_queryInterface
CORBA_boolean Evolution_Mail_Session_getProperties(Evolution_Mail_Session _obj, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev);
Evolution_Mail_StoreInfos* Evolution_Mail_Session_getStores(Evolution_Mail_Session _obj, const CORBA_char * pattern, const Evolution_Mail_StoreListener listener, CORBA_Environment *ev);
void Evolution_Mail_Session_addListener(Evolution_Mail_Session _obj, const Evolution_Mail_SessionListener listener, CORBA_Environment *ev);
void Evolution_Mail_Session_removeListener(Evolution_Mail_Session _obj, const Evolution_Mail_SessionListener listener, CORBA_Environment *ev);
#define Evolution_Mail_Store_ref Bonobo_Unknown_ref
#define Evolution_Mail_Store_unref Bonobo_Unknown_unref
#define Evolution_Mail_Store_queryInterface Bonobo_Unknown_queryInterface
CORBA_boolean Evolution_Mail_Store_getProperties(Evolution_Mail_Store _obj, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev);
Evolution_Mail_FolderInfos* Evolution_Mail_Store_getFolders(Evolution_Mail_Store _obj, const CORBA_char * pattern, const Evolution_Mail_FolderListener listener, CORBA_Environment *ev);
void Evolution_Mail_Store_sendMessage(Evolution_Mail_Store _obj, const Evolution_Mail_MessageStream msg, CORBA_Environment *ev);
#define Evolution_Mail_Folder_ref Bonobo_Unknown_ref
#define Evolution_Mail_Folder_unref Bonobo_Unknown_unref
#define Evolution_Mail_Folder_queryInterface Bonobo_Unknown_queryInterface
CORBA_boolean Evolution_Mail_Folder_getProperties(Evolution_Mail_Folder _obj, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev);
Evolution_Mail_MessageIterator Evolution_Mail_Folder_getMessages(Evolution_Mail_Folder _obj, const CORBA_char * pattern, CORBA_Environment *ev);
void Evolution_Mail_Folder_changeMessages(Evolution_Mail_Folder _obj, const Evolution_Mail_MessageInfoSets* infos, CORBA_Environment *ev);
Evolution_Mail_MessageStream Evolution_Mail_Folder_getMessage(Evolution_Mail_Folder _obj, const CORBA_char * uid, CORBA_Environment *ev);
void Evolution_Mail_Folder_appendMessage(Evolution_Mail_Folder _obj, const Evolution_Mail_MessageInfoSet* info, const Evolution_Mail_MessageStream msg, CORBA_Environment *ev);
#include <orbit/orb-core/orbit-interface.h>

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IInterface Evolution_Mail_MessageStream__iinterface;
#define Evolution_Mail_MessageStream_IMETHODS_LEN 2
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IMethod Evolution_Mail_MessageStream__imethods[Evolution_Mail_MessageStream_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IInterface Evolution_Mail_MessageIterator__iinterface;
#define Evolution_Mail_MessageIterator_IMETHODS_LEN 2
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IMethod Evolution_Mail_MessageIterator__imethods[Evolution_Mail_MessageIterator_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IInterface Evolution_Mail_SessionListener__iinterface;
#define Evolution_Mail_SessionListener_IMETHODS_LEN 2
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IMethod Evolution_Mail_SessionListener__imethods[Evolution_Mail_SessionListener_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IInterface Evolution_Mail_StoreListener__iinterface;
#define Evolution_Mail_StoreListener_IMETHODS_LEN 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IMethod Evolution_Mail_StoreListener__imethods[Evolution_Mail_StoreListener_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IInterface Evolution_Mail_FolderListener__iinterface;
#define Evolution_Mail_FolderListener_IMETHODS_LEN 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IMethod Evolution_Mail_FolderListener__imethods[Evolution_Mail_FolderListener_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IInterface Evolution_Mail_Session__iinterface;
#define Evolution_Mail_Session_IMETHODS_LEN 4
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IMethod Evolution_Mail_Session__imethods[Evolution_Mail_Session_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IInterface Evolution_Mail_Store__iinterface;
#define Evolution_Mail_Store_IMETHODS_LEN 3
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IMethod Evolution_Mail_Store__imethods[Evolution_Mail_Store_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IInterface Evolution_Mail_Folder__iinterface;
#define Evolution_Mail_Folder_IMETHODS_LEN 5
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static 
#else
extern 
#endif
ORBit_IMethod Evolution_Mail_Folder__imethods[Evolution_Mail_Folder_IMETHODS_LEN];

/** IMethods index */

#ifndef __Evolution_Mail_MessageStream__imethods_index
#define __Evolution_Mail_MessageStream__imethods_index
typedef enum {
	Evolution_Mail_MessageStream_next__imethods_index,
	Evolution_Mail_MessageStream_dispose__imethods_index
} Evolution_Mail_MessageStream__imethods_index;
#endif /* __Evolution_Mail_MessageStream__imethods_index */

#ifndef __Evolution_Mail_MessageIterator__imethods_index
#define __Evolution_Mail_MessageIterator__imethods_index
typedef enum {
	Evolution_Mail_MessageIterator_next__imethods_index,
	Evolution_Mail_MessageIterator_dispose__imethods_index
} Evolution_Mail_MessageIterator__imethods_index;
#endif /* __Evolution_Mail_MessageIterator__imethods_index */

#ifndef __Evolution_Mail_SessionListener__imethods_index
#define __Evolution_Mail_SessionListener__imethods_index
typedef enum {
	Evolution_Mail_SessionListener_changed__imethods_index,
	Evolution_Mail_SessionListener_shutdown__imethods_index
} Evolution_Mail_SessionListener__imethods_index;
#endif /* __Evolution_Mail_SessionListener__imethods_index */

#ifndef __Evolution_Mail_StoreListener__imethods_index
#define __Evolution_Mail_StoreListener__imethods_index
typedef enum {
	Evolution_Mail_StoreListener_changed__imethods_index
} Evolution_Mail_StoreListener__imethods_index;
#endif /* __Evolution_Mail_StoreListener__imethods_index */

#ifndef __Evolution_Mail_FolderListener__imethods_index
#define __Evolution_Mail_FolderListener__imethods_index
typedef enum {
	Evolution_Mail_FolderListener_changed__imethods_index
} Evolution_Mail_FolderListener__imethods_index;
#endif /* __Evolution_Mail_FolderListener__imethods_index */

#ifndef __Evolution_Mail_Session__imethods_index
#define __Evolution_Mail_Session__imethods_index
typedef enum {
	Evolution_Mail_Session_getProperties__imethods_index,
	Evolution_Mail_Session_getStores__imethods_index,
	Evolution_Mail_Session_addListener__imethods_index,
	Evolution_Mail_Session_removeListener__imethods_index
} Evolution_Mail_Session__imethods_index;
#endif /* __Evolution_Mail_Session__imethods_index */

#ifndef __Evolution_Mail_Store__imethods_index
#define __Evolution_Mail_Store__imethods_index
typedef enum {
	Evolution_Mail_Store_getProperties__imethods_index,
	Evolution_Mail_Store_getFolders__imethods_index,
	Evolution_Mail_Store_sendMessage__imethods_index
} Evolution_Mail_Store__imethods_index;
#endif /* __Evolution_Mail_Store__imethods_index */

#ifndef __Evolution_Mail_Folder__imethods_index
#define __Evolution_Mail_Folder__imethods_index
typedef enum {
	Evolution_Mail_Folder_getProperties__imethods_index,
	Evolution_Mail_Folder_getMessages__imethods_index,
	Evolution_Mail_Folder_changeMessages__imethods_index,
	Evolution_Mail_Folder_getMessage__imethods_index,
	Evolution_Mail_Folder_appendMessage__imethods_index
} Evolution_Mail_Folder__imethods_index;
#endif /* __Evolution_Mail_Folder__imethods_index */

#ifndef __ORBIT_IMETHODS_INDEX
#define __ORBIT_IMETHODS_INDEX
#define ORBIT_IMETHODS_INDEX(m) (m ## __imethods_index)
#endif /* __ORBIT_IMETHODS_INDEX */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#ifndef EXCLUDE_ORBIT_H
#include <orbit/orbit.h>

#endif /* EXCLUDE_ORBIT_H */
#endif
#undef ORBIT_IDL_SERIAL
